<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>A repülőgép üzemmód engedélyezve</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>A repülőgép üzemmód letiltva</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Letiltás</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Repülőgép üzemmód</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Repülőgép üzemmód beállításai</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Repülőgép üzemmód</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Eszközeim</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth beállítások</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Kikapcsolva</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Bekapcsolás</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth beállítások</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 kapcsolódva</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Kapcsolódás...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Kikapcsolva</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 csatlakoztatva</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nincs kapcsolódva</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Fényerősség</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Képernyő beállítások</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Képernyő beállítások</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Fényerősség</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>V.</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>H.</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>K.</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Sze.</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Cs.</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>P.</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Szo.</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Billentyűzetkiosztás megadása</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dátum és Idő</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 órás időformátum</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 órás időformátum</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Idő beállításai</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Naptár megnyitása</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Kedd</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Szerda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Csütörtök</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Péntek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Szombat</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Vasárnap</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Kedd</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Szerda</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Csütörtök</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Péntek</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Szombat</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>Vasárnap</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Egyéb eszközök</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Ne zavarjanak üzemmód</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Ne zavarjanak üzemmód beállításai</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Letiltás</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>A ne zavarjanak üzemmód engedélyezve</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>A ne zavarjanak üzemmód letiltva</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Ne zavarjanak üzemmód</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Szemkímélés</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Szemkímélés engedélyezve</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Szemkímélés letíltva</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Képernyő beállítások</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Szemkímélés</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Téma</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Be</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Világos</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Sötét</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>A szemkímélés letiltása</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>A szemkímélés engedélyezése</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Képernyő beállítások</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Téma: Világos</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Téma: Sötét</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Téma: Automatikus</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Vizuális effektusok</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Világos</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Sötét</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Téma</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Nincsenek üzenetek</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Értesítési beállítások</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Értesítések</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Ne zavarjanak üzemmód kikapcsolása</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Ne zavarjanak üzemmód bekapcsolása</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Értesítések</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Képernyő billentyűzet</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Magas teljesítmény </translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Kiegyensúlyozott</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Energiatakarékos</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Kiegyensúlyozott teljesítményű</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Akkumulátor töltöttsége %1, %2 perc van még hátra a feltöltésig</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Akkumulátor töltöttsége %1, %2 óra %3 perc van még hátra a feltöltésig</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Töltés %1, %2 perc van a feltöltés befejezéséig</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Töltés %1, %2 óra %3 perc van a feltöltés befejezéséig</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Akkumulátor töltöttsége %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Töltés %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Akkumulátor töltöttsége %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Akkumulátor töltöttsége %1, teljesen feltöltve</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Akkumulátor töltöttsége %1, nem tölt</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Akkumulátor</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Töltés, becsült töltési idő kiszámítása</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>A hátralévő használati idő kiszámítása</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 perc van hátra</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 óra %2 perc van hátra</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Nem töltődik</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Teljesen feltöltve</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Töltés, %1 perc van hátra a teljes feltöltésig</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Töltés, %1 óra %2 perc van hátra a teljes feltöltésig</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Akkumulátor töltöttsége %1, %2 óra van még hátra</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 óra van hátra</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Töltés %1, %2 óra van hátra a teljes feltöltésig</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Töltés, %1 óra van hátra a teljes feltöltésig</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Zene</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Frissítés és Leállítás</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Frissítés és Újraindítás</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Felhasználóváltás</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Ma</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Hold naptár</translation>
    </message>
    <message>
        <source>y</source>
        <translation>év</translation>
    </message>
    <message>
        <source>m</source>
        <translation>hó</translation>
    </message>
    <message>
        <source>d</source>
        <translation>nap</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Kedd</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Szerda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Csütörtök</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Péntek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Szombat</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Vasárnap</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Jan.</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Febr.</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Márc.</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Ápr.</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Máj.</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Jún.</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Júl.</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Aug.</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Szept.</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Okt.</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nov.</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dec.</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Naptár megnyitása</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Kedd</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Szerda</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Csütörtök</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Péntek</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Szombat</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>Vasárnap</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Hangerő</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Kimenet</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Hang beállítások</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Hangok</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Némítás visszavonása</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Hang beállítások</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Nincsenek kimeneti eszközök</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Hangerő: %1</translation>
    </message>
</context>
</TS>